import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Manage an access token for a Rollbar project.
 *
 * @schema CfnAccessTokenProps
 */
export interface CfnAccessTokenProps {
    /**
     * The project ID
     *
     * @schema CfnAccessTokenProps#ProjectId
     */
    readonly projectId: number;
    /**
     * Name to identify the access token
     *
     * @schema CfnAccessTokenProps#Name
     */
    readonly name: string;
    /**
     * Scopes to assign to the create access token
     *
     * @schema CfnAccessTokenProps#Scopes
     */
    readonly scopes: CfnAccessTokenPropsScopes[];
    /**
     * Period of time (in seconds) for the rate limit configuration
     *
     * @schema CfnAccessTokenProps#RateLimitWindowSize
     */
    readonly rateLimitWindowSize?: number;
    /**
     * Number of requests for the defined rate limiting period
     *
     * @schema CfnAccessTokenProps#RateLimitWindowCount
     */
    readonly rateLimitWindowCount?: number;
}
/**
 * Converts an object of type 'CfnAccessTokenProps' to JSON representation.
 */
export declare function toJson_CfnAccessTokenProps(obj: CfnAccessTokenProps | undefined): Record<string, any> | undefined;
/**
 * @schema CfnAccessTokenPropsScopes
 */
export declare enum CfnAccessTokenPropsScopes {
    /** write */
    WRITE = "write",
    /** read */
    READ = "read",
    /** post_server_item */
    POST_SERVER_ITEM = "post_server_item",
    /** post_client_item */
    POST_CLIENT_ITEM = "post_client_item"
}
/**
 * A CloudFormation `Rollbar::Projects::AccessToken`
 *
 * @cloudformationResource Rollbar::Projects::AccessToken
 * @stability external
 * @link https://github.com/aws-ia/cloudformation-rollbar-resource-providers.git
 */
export declare class CfnAccessToken extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "Rollbar::Projects::AccessToken";
    /**
     * Resource props.
     */
    readonly props: CfnAccessTokenProps;
    /**
     * Attribute `Rollbar::Projects::AccessToken.AccessToken`
     * @link https://github.com/aws-ia/cloudformation-rollbar-resource-providers.git
     */
    readonly attrAccessToken: string;
    /**
     * Attribute `Rollbar::Projects::AccessToken.Status`
     * @link https://github.com/aws-ia/cloudformation-rollbar-resource-providers.git
     */
    readonly attrStatus: string;
    /**
     * Create a new `Rollbar::Projects::AccessToken`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnAccessTokenProps);
}
